==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/TreemapNodePointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodePointerEventArgsDescription } from "./TreemapNodePointerEventArgsDescription";
/**
 * @hidden
 */
var TreemapNodePointerEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TreemapNodePointerEventArgsDescriptionMetadata, _super);
    function TreemapNodePointerEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TreemapNodePointerEventArgsDescriptionMetadata.b = function (a) {
        if (TreemapNodePointerEventArgsDescriptionMetadata.a == null) {
            TreemapNodePointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TreemapNodePointerEventArgsDescriptionMetadata.c(TreemapNodePointerEventArgsDescriptionMetadata.a);
        }
        if (a.k(TreemapNodePointerEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(TreemapNodePointerEventArgsDescriptionMetadata.a);
    };
    TreemapNodePointerEventArgsDescriptionMetadata.c = function (a) {
        a.item("Value", "Number:double");
        a.item("Sum", "Number:double");
        a.item("CustomValueRef", "(w:CustomValue,wf:CustomValue)DataRef");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("ParentItemRef", "(w:ParentItem,wf:ParentItem)DataRef");
        a.item("Position", "Point");
        a.item("IsRightButton", "Boolean");
        a.item("IsHandled", "Boolean");
        a.item("IsOverHeader", "Boolean");
        a.item("Label", "String");
        a.item("ParentValue", "Number:double");
        a.item("ParentLabel", "String");
        a.item("ParentSum", "Number:double");
    };
    TreemapNodePointerEventArgsDescriptionMetadata.d = function (a) {
        TreemapNodePointerEventArgsDescriptionMetadata.b(a);
        a.ad("TreemapNodePointerEventArgs", function () { return new TreemapNodePointerEventArgsDescription(); });
        a.ac("TreemapNodePointerEventArgs", TreemapNodePointerEventArgsDescriptionMetadata.a);
    };
    TreemapNodePointerEventArgsDescriptionMetadata.$t = markType(TreemapNodePointerEventArgsDescriptionMetadata, 'TreemapNodePointerEventArgsDescriptionMetadata');
    TreemapNodePointerEventArgsDescriptionMetadata.a = null;
    return TreemapNodePointerEventArgsDescriptionMetadata;
}(Base));
export { TreemapNodePointerEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/TreemapNodePointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodePointerEventArgsDescription } from "./TreemapNodePointerEventArgsDescription";
/**
 * @hidden
 */
var TreemapNodePointerEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TreemapNodePointerEventArgsDescriptionMetadata, _super);
    function TreemapNodePointerEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TreemapNodePointerEventArgsDescriptionMetadata.b = function (a) {
        if (TreemapNodePointerEventArgsDescriptionMetadata.a == null) {
            TreemapNodePointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TreemapNodePointerEventArgsDescriptionMetadata.c(TreemapNodePointerEventArgsDescriptionMetadata.a);
        }
        if (a.k(TreemapNodePointerEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(TreemapNodePointerEventArgsDescriptionMetadata.a);
    };
    TreemapNodePointerEventArgsDescriptionMetadata.c = function (a) {
        a.item("Value", "Number:double");
        a.item("Sum", "Number:double");
        a.item("CustomValueRef", "(w:CustomValue,wf:CustomValue)DataRef");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("ParentItemRef", "(w:ParentItem,wf:ParentItem)DataRef");
        a.item("Position", "Point");
        a.item("IsRightButton", "Boolean");
        a.item("IsHandled", "Boolean");
        a.item("IsOverHeader", "Boolean");
        a.item("Label", "String");
        a.item("ParentValue", "Number:double");
        a.item("ParentLabel", "String");
        a.item("ParentSum", "Number:double");
    };
    TreemapNodePointerEventArgsDescriptionMetadata.d = function (a) {
        TreemapNodePointerEventArgsDescriptionMetadata.b(a);
        a.ae("TreemapNodePointerEventArgs", function () { return new TreemapNodePointerEventArgsDescription(); });
        a.ad("TreemapNodePointerEventArgs", TreemapNodePointerEventArgsDescriptionMetadata.a);
    };
    TreemapNodePointerEventArgsDescriptionMetadata.$t = markType(TreemapNodePointerEventArgsDescriptionMetadata, 'TreemapNodePointerEventArgsDescriptionMetadata');
    TreemapNodePointerEventArgsDescriptionMetadata.a = null;
    return TreemapNodePointerEventArgsDescriptionMetadata;
}(Base));
export { TreemapNodePointerEventArgsDescriptionMetadata };
